Neutral Deltas
==============

The neutral deltas module provides lookups for neutral losses and gains.



.. automodule:: tacular.neutral_deltas
   :members:
   :undoc-members:
   :show-inheritance:
